import numpy as np


def sin_wave(f: float, A: float, phi: float, t: float) -> float:
    
    return A*np.sin(2*np.pi*f*t + phi*(np.pi/180))

def square_wave1(frequency, duty_cycle, max_value, min_value, duration, sampling_rate):
    """
    Generate a square wave signal.
    
    Parameters:
    frequency (float): Frequency of the square wave in Hz
    duty_cycle (float): Duty cycle of the square wave (0 to 1)
    max_value (float): Maximum value of the square wave
    min_value (float): Minimum value of the square wave
    duration (float): Duration of the signal in seconds
    sampling_rate (float): Sampling rate in samples per second
    
    Returns:
    t (numpy array): Time array
    square_wave (numpy array): Square wave signal
    """
    t = np.linspace(0, duration, int(sampling_rate * duration), endpoint=False)
    period = 1.0 / frequency
    square_wave = np.where((t % period) < (duty_cycle * period), max_value, min_value)
    return t, square_wave

def square_wave(frequency, duty_cycle, max_value, min_value, t):
    """
    Generate a square wave signal.
    
    Parameters:
    frequency (float): Frequency of the square wave in Hz
    duty_cycle (float): Duty cycle of the square wave (0 to 1)
    max_value (float): Maximum value of the square wave
    min_value (float): Minimum value of the square wave
    t (float  or numpy array): Time array
    
    Returns:
    square_wave (float  or numpy array): Square wave signal
    """
    period = 1.0 / frequency
    square_wave = np.where((t % period) < (duty_cycle * period), max_value, min_value)
    return square_wave


if __name__ == '__main__':
    import matplotlib.pyplot as plt
    t = []
    y2=[]
    y3=[]
    # t,y2 = square_wave(20,0.5,1,-1,1,1000)
    duration=5
    sampling_rate=1000
    for i in range(duration*sampling_rate):
        t.append(i/sampling_rate)
    
        y2.append(square_wave(60, 0.5,1,-1, i/sampling_rate))
        y3.append(sin_wave(60, 1, 0, i/sampling_rate)) 
    
    plt.xlabel('time')
    plt.ylabel('amplitude')
    plt.grid()
    plt.plot(t,y2)
    plt.plot(t,y3)
    plt.show()
    
   


import sys
import os
sys.path.append(os.path.join(os.path.dirname(__file__), '..\\'))
import cloudpss
import time
import numpy as np
import pandas as pd
import json

if __name__ == '__main__':
    os.environ['CLOUDPSS_API_URL'] = 'http://cloudpss-calculate.local.ddns.cloudpss.net/'
    print('CLOUDPSS connected')
    cloudpss.setToken(
        'eyJhbGciOiJFUzI1NiIsInR5cCI6IkpXVCJ9.eyJpZCI6MSwidXNlcm5hbWUiOiJhZG1pbiIsInNjb3BlcyI6WyJtb2RlbDo5ODM2NyIsImZ1bmN0aW9uOjk4MzY3IiwiYXBwbGljYXRpb246MzI4MzEiXSwicm9sZXMiOlsiYWRtaW4iXSwidHlwZSI6ImFwcGx5IiwiZXhwIjoxNzQ5NzE2MzczLCJub3RlIjoiYWQiLCJpYXQiOjE3MTg2MTIzNzN9.XyaWizYSeT-AQAdndukdbUrS38DcWL4z85kIzBZCpAjwyCKbFVqX68xZGpkM8Pr5IX0yUHnZT93KNWJVpCXVAA')
    print('Token done')
    project = cloudpss.Model.fetch('model/CloudPSS/IEEE39')
    print(project.revision.hash)
    t = time.time()
    # topology = cloudpss.ModelTopology.fetch("hlbBPYIyQHWzgPxdjp9lV9a92twyxA2zETzrqz4Q0fou7mfOemX-pr9OfO9eUfq4","emtp",{'args':{}})
    # topology = cloudpss.ModelTopology.fetch("JwHbZdjco9eC0nZw3fY7Iz9rqsQ4HFGJObiBW3bFuYLPCd0Vqb2vb8zNY28D1AXV","emtp",{'args':{}})
    print(time.time()-t)
    
    runner = project.run()
    while not runner.status():
        logs = runner.result.getLogs()
        for log in logs:
            print(log)
    logs = runner.result.getLogs()
    for log in logs:
        print(log)     

    # topology= project.fetchTopology(config={'args':{}},maximumDepth=10)

    # topology.dump(topology,'test.json')
    
    
    


from .IESLabSimulation import IESLabSimulation
from .IESLabPlan import IESLabPlan
from .PlanModel import OptimizationMode
from .IESLabOpt import IESLabOpt
__all__ = ['IESLabSimulation','IESLabPlan', 'OptimizationMode', 'IESLabOpt']



import time

def sleep_microseconds(microseconds):
    start_time = time.perf_counter()
    end_time = start_time + microseconds / 1_000_000  # 将微秒转换为秒
    while time.perf_counter() < end_time:
        pass

# 睡眠500微秒（0.5毫秒）
print("Sleeping for 500 microseconds")
sleep_microseconds(500)
print("Awake!")

# 测量实际睡眠时间
start_time = time.perf_counter()
# sleep_microseconds(10)
time.sleep(0.05)
end_time = time.perf_counter()

elapsed_time = (end_time - start_time) * 1_000_000  # 将秒转换为微秒
print(f"实际睡眠时间: {elapsed_time:.2f} 微秒")